## 自己手写的 logger
>不喜勿喷
---
Eg:
```python
import msdnicrosoft_logger
logger = msdnicrosoft_logger.Log(Console=True,File=True)
# Args:
# Console :: Output messages to Console
#
# File :: Output messages to files
# ... Enter your code there
```

